/* Night
 *
 * Version 1.4
 * 2/19/2021
 *
 * Constants for color codes
 *
 * Functions declared:
 *
 * int ftype(char file[])
 * 
 *	-- returns integer representing a file type; 0 (_NONE), 1 (_FILE), 2 (_DIR)
 *
 * char * substr(char string[], char find[], char replace[])
 * 
 *	-- replaces all instances of 'find' with 'replace' in 'string'
 * 	   Note: 'find' and 'replace' must be the same length. Used by night() and nightfile().
 * 
 * char * night(char string[])
 * 
 *	-- interprets text and Night codes in 'string', returning the result
 *
 * int nightfile(char file[])
 * 
 *	-- interprets text and Night codes in 'file', displaying the result
 *
 * night.h
 */

#ifndef _NIGHT_H
#define _NIGHT_H 1

#define Code_Black    "~BLAK"
#define Code_Red      "~REDX"
#define Code_Green    "~GREE"
#define Code_Yellow   "~YELL"
#define Code_Blue     "~BLUE"
#define Code_Purple   "~PURP"
#define Code_Cyan     "~CYAN"
#define Code_White    "~WHIT"
#define Code_Bold     "~BLD"
#define Code_Line     "~LIN"
#define Code_Clear    "~CLR"
#define Code_Cursor   "~CUR"
#define Code_Reverse  "~REV"
#define Code_Reset    "~RES"

#define BLACK   "\e[30m"
#define RED     "\e[31m"
#define GREEN   "\e[32m"
#define YELLOW  "\e[33m"
#define BLUE    "\e[34m"
#define PURPLE  "\e[35m"
#define CYAN    "\e[36m"
#define WHITE   "\e[37m"
#define BOLD    "\e[1m"
#define LINE    "\e[4m"
#define CLEAR   "\e[2J"
#define CURSOR  "\e[;H"
#define REVERSE "\e[7m"
#define RESET   "\e[0m"

#define CODE_TABLE "\
  Color | Code	     Effect | Code\n\
  ______|_____	     _______|_____\n\
  "BLACK"black"RESET" | ~BLAK	      "BOLD"bold"RESET" | ~BLD\n\
    "RED"red"RESET" | ~REDX	 "LINE"underline"RESET" | ~LIN\n\
  "GREEN"green"RESET" | ~GREE	     clear | ~CLR\n\
 "YELLOW"yellow"RESET" | ~YELL	    cursor | ~CUR\n\
   "BLUE"blue"RESET" | ~BLUE	   "REVERSE"reverse"RESET" | ~REV\n\
 "PURPLE"purple"RESET" | ~PURP	     reset | ~RES\n\
   "CYAN"cyan"RESET" | ~CYAN\n\
  "WHITE"white"RESET" | ~WHIT\n\
  "BOLD BLACK"black"RESET" | ~BLD~BLAK\n\
    "BOLD RED"red"RESET" | ~BLD~REDX\n\
  "BOLD GREEN"green"RESET" | ~BLD~GREE\n\
 "BOLD YELLOW"yellow"RESET" | ~BLD~YELL\n\
   "BOLD BLUE"blue"RESET" | ~BLD~BLUE\n\
 "BOLD PURPLE"purple"RESET" | ~BLD~PURP\n\
   "BOLD CYAN"cyan"RESET" | ~BLD~CYAN\n\
  "BOLD WHITE"white"RESET" | ~BLD~WHIT\n"

/* Global variables */
char b[512];
char n[512];
char string[512];

/* Function declarations */
extern int ftype(char file[]);
extern char * substr(char string[], char find[], char replace[]);
extern char * night(char string[]);
extern int nightfile(char file[]);

#endif /* _NIGHT_H */
